import inspect
import json
import threading
from calendar import monthrange
from datetime import datetime
from sys import exc_info, argv
from time import sleep, time
from urllib.parse import unquote, parse_qs, urlparse
from uuid import getnode

from art import text2art
from colorama import Fore
from ntplib import NTPClient
from phonenumbers import region_code_for_number, parse

from autowebx.files import add

__lock = threading.Lock()


class AccountError(Exception):
    """Raised when an account fails to create"""


def int_input(prompt: str, default: int = 1) -> int:
    try:
        return int(input(prompt))
    except ValueError:
        return default


def intro(name: str):
    user_id = getnode()
    sync_print('=' * 85)
    sync_print(f'{Fore.LIGHTYELLOW_EX}{text2art("Hazem3010", "banner3")}')
    indent = " " * int((85 - len(f'{name}    ::    Your ID: {user_id}')) / 2)
    sync_print(f'{indent}{Fore.GREEN}{name}{Fore.LIGHTMAGENTA_EX}    ::    {Fore.CYAN}Your ID: {user_id}{Fore.RESET}')
    sync_print('=' * 85)
    return str(user_id)


class PhoneNumber:
    def __init__(self, phone_number):
        self.number = phone_number
        parsed_number = parse(f'+{phone_number}')
        self.prefix = parsed_number.country_code
        self.country = region_code_for_number(parsed_number)


def sync_print(*content, end: str = '\n'):
    __lock.acquire()
    print(*content, end=end, flush=True)
    add(f"{' '.join(map(str, content))}{end}", 'output.txt')
    __lock.release()


class URL:
    def __init__(self, url: str):
        self.__parameters__ = parse_qs(urlparse(url).query)

    def get(self, parameter: str) -> str:
        return self.__parameters__.get(parameter)[0]


def __get_function__() -> None:
    http = argv[1]
    http_content = open(http, 'r').read()
    lines = http_content.split('\n')
    method, endpoint, _ = lines[0].split(' ')
    endpoint = unquote(endpoint).replace("\"", "\\\"")

    # Extract headers properly
    headers = {}
    host = ""
    for line in lines[1:]:
        if line == '':
            break
        line_data = line.split(':', 1)
        if len(line_data) == 2:
            key, value = line_data[0].strip(), unquote(line_data[1].strip())
            headers[key] = value
            if key.lower() == "host":
                host = value

    if not host:
        raise ValueError("Host header is missing in the request")

    result = f'def function(self):    # {http}\n    url = "https://{host}{endpoint}"\n\n'

    result += "    headers = {\n"
    for key, value in headers.items():
        result += f"        '{key}': '{value}',\n"
    result = result[:-2] + "\n    }\n\n"

    content = http_content.split('\n\n')
    with_payload = False
    json_payload = False
    if len(content) > 1 and content[1] != '':
        with_payload = True
        result += '    payload = '
        variables_content = content[1].strip()
        if variables_content.startswith('{'):
            payload = json.loads(variables_content)
            json_payload = True
        else:
            variables = content[1].strip().split('&')
            payload = {}
            for item in variables:
                try:
                    pair = item.split('=')
                    payload[pair[0]] = unquote(pair[1])
                except IndexError:
                    pass

        payload = json.dumps(payload, indent=4).replace('\n', '\n    ').replace(': true', ': True')
        payload = payload.replace(': false', ': False')
        result += unquote(payload)
        result = result + '\n\n'

    args = f'(url, headers=headers{", json=payload)" if json_payload else ", data=payload)" if with_payload else ")"}'
    result += f'    response = self.session.{method.lower()}{args}\n'
    result = result.replace('\t', '    ')

    open('function.py', 'w', encoding='UTF-8').write(result)


def ranges(numbers: list[str]) -> list[str]:
    return list({number[:-3] for number in numbers})


def days_in_month(year: int, month: int) -> int:
    return monthrange(year, month)[1]


def handle_threads(threads: int, total: int, target) -> None:
    for i in range(1, total + 1):
        target(count=i).start()
        while True:
            active = 0
            for thread in threading.enumerate():
                if thread.name.startswith('Task_'):
                    active += 1
            if active < threads:
                break
            sleep(1)

    done = False
    while not done:
        done = True
        for thread in threading.enumerate():
            if thread.name.startswith('Task_'):
                done = False
                break



def var_name(var):
    for name, value in inspect.stack()[1].frame.f_locals.items():
        if value is var:
            return name
    return None


useragents = [
    "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/123.0.0.0 Safari/537.36",
    "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:124.0) Gecko/20100101 Firefox/124.0",
    "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/123.0.0.0 "
    "Safari/537.36 Edg/123.0.2420.81",
    "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/123.0.0.0 "
    "Safari/537.36 OPR/109.0.0.0",
    "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/123.0.0.0 "
    "Safari/537.36",
    "Mozilla/5.0 (Macintosh; Intel Mac OS X 14.4; rv:124.0) Gecko/20100101 Firefox/124.0",
    "Mozilla/5.0 (Macintosh; Intel Mac OS X 14_4_1) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/17.4.1 "
    "Safari/605.1.15",
    "Mozilla/5.0 (Macintosh; Intel Mac OS X 14_4_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/123.0.0.0 "
    "Safari/537.36 OPR/109.0.0.0",
    "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/123.0.0.0 Safari/537.36",
    "Mozilla/5.0 (X11; Linux i686; rv:124.0) Gecko/20100101 Firefox/124.0"
]

__locales_str = (
    "af_ZAam_ETar_AEar_BHar_DZar_EGar_IQar_JOar_KWar_LBar_LYar_MAar_OMar_QAar_SAar_SDar_SYar_TNar_YEaz_AZbe_BYbg_BGbn_B"
    "Dbn_INbs_BAca_EScs_CZcy_GBda_DKde_ATde_BEde_CHde_DEde_LIde_LUdv_MVel_CYel_GRen_AUen_BWen_CAen_GBen_HKen_IEen_INen_"
    "JMen_MHen_MTen_NAen_NZen_PHen_PKen_SGen_TTen_USen_ZAen_ZWes_ARes_BOes_CLes_COes_CRes_DOes_ECes_ESes_GTes_HNes_MXes"
    "_NIes_PAes_PEes_PRes_PYes_SVes_USes_UYes_VEet_EEeu_ESfa_IRfi_FIfo_FOfr_BEfr_BFfr_BIfr_BJfr_BLfr_CAfr_CDfr_CFfr_CGf"
    "r_CHfr_CIfr_CMfr_DJfr_FRfr_GAfr_GFfr_GNfr_GPfr_GQfr_HTfr_KMfr_LUfr_MAfr_MCfr_MFfr_MGfr_MLfr_MQfr_NEfr_PFfr_PMfr_RE"
    "fr_RWfr_SCfr_SNfr_SYfr_TDfr_TGfr_TNfr_VUfr_WFfr_YTga_IEgl_ESgu_INha_NGhe_ILhi_INhr_BAhr_HRhu_HUhy_AMid_IDig_NGis_I"
    "Sit_CHit_ITja_JPka_GEkk_KZkm_KHkn_INko_KRky_KGlo_LAlt_LTlv_LVmg_MGmk_MKml_INmn_MNmr_INms_BNms_MYmt_MTnb_NOne_NPnl_"
    "AWnl_BEnl_NLnn_NOom_ETor_INpa_INpl_PLps_AFpt_AOpt_BRpt_CHpt_CVpt_FRpt_GQpt_GWpt_LUpt_MOpt_MZpt_PTpt_STpt_TLro_MDro"
    "_ROru_BYru_KGru_KZru_MDru_RUru_UArw_RWsd_INsi_LKsk_SKsl_SIso_DJso_ETso_KEso_SOsq_ALsr_BAsr_MEsr_RSsv_AXsv_FIsv_SEs"
    "w_CDsw_KEsw_TZsw_UGta_INta_LKte_INth_THti_ERti_ETtl_PHtn_BWtn_ZAtr_CYtr_TRug_CNuk_UAur_INur_PKuz_AFuz_UZvi_VNyo_NG"
    "zh_CNzh_HKzh_MOzh_SGzh_TWzu_ZA"
)


def locales():
    return [__locales_str[i:i + 5] for i in range(0, len(__locales_str), 5)]


def exception_line():
    return exc_info()[-1].tb_lineno


def internet_time():
    return datetime.fromtimestamp(NTPClient().request('pool.ntp.org').tx_time)


class Timer:
    def __init__(self, timeout, message):
        self.timeout = timeout
        self.start = time()
        self.message = message

    def __call__(self):
        if time() - self.start > self.timeout:
            raise TimeoutError(self.message)



from random import randint
from time import time, sleep

from requests import post


class RecaptchaV2:
    def __init__(self, apikey: str, website_url: str, website_key: str, is_invisible: bool = False):
        self.client_key = apikey

        data = {
            "clientKey": apikey,
            "task": {
                "type": "RecaptchaV2TaskProxyless",
                "websiteURL": website_url,
                "websiteKey": website_key,
                "isInvisible": is_invisible
            }
        }

        response = post('https://api.capsolver.com/createTask', json=data).json()
        self.task_id = response['taskId']
        self.submit_time = time()

    def solution(self, timeout=randint(15, 20)):
        while time() < self.submit_time + timeout:
            pass

        data = {
            "clientKey": self.client_key,
            "taskId": self.task_id
        }

        while True:
            response = post('https://api.capsolver.com/getTaskResult', json=data).json()
            if response['status'] == 'processing':
                sleep(5)
            elif error_id := response['errorId'] != 0:
                raise Exception(f'{error_id}:{response["errorCode"]}:{response["errorDescription"]}')
            else:
                return response['solution']['gRecaptchaResponse']



import re
from time import time
from bs4 import BeautifulSoup, Tag, ResultSet
from requests import get, post


def get_suggestions():
    html = get("https://tempm.com/").text
    soup = BeautifulSoup(html, "html.parser")
    return [child.text for child in soup.find('div', class_="tt-suggestions").children]


def get_message(email: str, timeout: int | float = 30) -> Tag | ResultSet[Tag]:
    url = "https://tempm.com/"
    username, domain = email.split("@")
    surl = f'{domain}/{username}'
    start = time()
    exception = None
    while time() - start < timeout:
        try:
            response = get(url, cookies={'surl': surl})
            soup = BeautifulSoup(response.text, 'html.parser')
            tag = soup.find('div', class_='mess_bodiyy')
            if tag:
                delll = re.search(r'delll: "([^"]+)"', response.text).group(1)
                cookies = {'surl': surl, 'embx': f'["{email}"]'}
                post('https://tempm.com/del_mail.php', {'delll': delll}, cookies=cookies)
                return tag
            else:
                exception = TimeoutError("No message received")
            tags = soup.select('#email-table a')
            if len(tags) > 0:
                return tags
        except ConnectionError:
            exception = ConnectionError("There is no connection")
    raise exception



import random


# noinspection HttpUrlsUsage
class Proxy:
    def __init__(
            self, text: str
    ):
        info = text.split('@')
        if len(info) == 2:
            authentication_information, self.server = info
            self.username, self.password = authentication_information.split(':')
        else:
            info = text.split(':')
            if len(info) == 2:
                self.username = self.password = None
                self.server = text
            elif len(info) == 4:
                self.username = info[2]
                self.password = info[3]
                self.server = f'{info[0]}:{info[1]}'
            else:
                raise TypeError(f"""Proxy must have one of the following formats:
                                    username:password@proxyserver:port
                                    proxy-server:port:username:password
                                    proxy-server:port
                                """)

    def for_requests(self):
        if self.username and self.password:
            server = f'http://{self.username}:{self.password}@{self.server}'
        else:
            server = f'http://{self.server}'
        return {"http": server, 'https': server}

    def for_playwright(self):
        return {
            'server': f'http://{self.server}',
            'username': self.username,
            'password': self.password,
        } if self.username and self.password else {'server': f'http://{self.server}'}


class LunaProxy(Proxy):
    __host_prefixes = ['pr', 'as', 'eu', 'na']

    def __init__(self, username: str, password: str, region: str | None = None, session_time: int = 3):
        super().__init__('0:0')
        self.username = f'user-{username}{f"-region-{region}" if region else ""}-sesstime-{session_time}'
        self.password = password
        self.server = f'{random.choice(LunaProxy.__host_prefixes)}.lunaproxy.com:12233'


if __name__ == '__main__':
    LunaProxy('khaled_L3yuV', 'bfdskjfsd456fD', 'ps')



import queue
import threading
import time
import json
from abc import ABC
from collections import deque
from collections.abc import Iterable
from threading import Event


class AutoSaveQueue(queue.Queue, Iterable, ABC):
    def __init__(self, file_path, auto_save_interval=5, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.file_path = file_path
        self.auto_save_interval = auto_save_interval
        self._stop_event = Event()
        self._start_auto_save()

    def _start_auto_save(self):
        """Start the auto-save thread that saves the queue to the file at regular intervals."""
        self.auto_save_thread = threading.Thread(target=self._auto_save)
        self.auto_save_thread.daemon = True
        self.auto_save_thread.start()

    def _auto_save(self):
        """Automatically save the queue to a file at regular intervals."""
        while not self._stop_event.is_set():
            self.save()
            time.sleep(self.auto_save_interval)

    def save(self):
        """Save the current state of the queue to a file."""
        with self.mutex:
            open(self.file_path, 'w').write('\n'.join(str(item) for item in self))

    def stop(self):
        """Stop the auto-save thread."""
        self._stop_event.set()
        self.auto_save_thread.join()

    def put(self, item, *args, **kwargs):
        """Override the put method to save after adding an item."""
        super().put(item, *args, **kwargs)
        self.save()

    def get(self, *args, **kwargs):
        """Override the get method to save after removing an item."""
        item = super().get(*args, **kwargs)
        self.save()
        return item

    def load(self):
        """Load the queue from a file."""
        try:
            with open(self.file_path, 'r') as f:
                data = json.load(f)
                with self.mutex:
                    self.queue = deque(data)
        except (FileNotFoundError, json.JSONDecodeError):
            pass  # Ignore errors when the file doesn't exist or is empty

# Usage
auto_queue = AutoSaveQueue("queue_data.json", auto_save_interval=10)
auto_queue.put("task 1")
auto_queue.put("task 2")



import random

from requests import get, post

from autowebx.account import Account

_BASE_URL = 'https://api.mail.tm'
_DOMAINS = None

def domains():
    global _DOMAINS
    if _DOMAINS:
        return _DOMAINS

    response = get(_BASE_URL + '/domains').json()
    _DOMAINS = [member.get('domain') for member in response.get('hydra:member')]
    return _DOMAINS


class Message:
    def __init__(self, message_id: str, text: str, html: list[str]):
        self.id = message_id
        self.text = text
        self.html = html


class MailTmAccount(Account):
    def __init__(self, **kwargs):
        if not kwargs.get('domain'):
            kwargs['domain'] = random.choice(domains())

        super().__init__(**kwargs)
        post(f'{_BASE_URL}/accounts', json={'address': self.email, 'password': self.password})
        response = post(_BASE_URL + '/token', json={'address': self.email, 'password': self.password}).json()
        self.token = response['token']

    def messages(self):
        response = get(_BASE_URL + '/messages', headers={'Authorization': f'Bearer {self.token}'}).json()
        return [self._message(message['id']) for message in response['hydra:member']]

    def _message(self, message_id: str):
        response = get(f'{_BASE_URL}/messages/{message_id}', headers={'Authorization': f'Bearer {self.token}'}).json()
        return Message(message_id, response['text'], response['html'])



from time import time, sleep

from requests import Session


class Message:
    def __init__(self, uid, sender, subject, received, receiver):
        self.id = uid
        self.sender = sender
        self.subject = subject
        self.received = received
        self.receiver = receiver


class Inboxes:
    def __init__(self, email,  timeout: int = 30):
        url = "https://inboxes.com/api/v2/domain"

        headers = {
            'Host': 'inboxes.com',
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:130.0) Gecko/20100101 Firefox/130.0',
            'Accept': '*/*',
            'Accept-Language': 'en-US,en;q=0.5',
            'Accept-Encoding': 'gzip, deflate',
            'Referer': 'https://inboxes.com/',
            'DNT': '1',
            'Sec-GPC': '1',
            'Connection': 'close',
            'Sec-Fetch-Dest': 'empty',
            'Sec-Fetch-Mode': 'cors',
            'Sec-Fetch-Site': 'same-origin',
            'Priority': 'u=0'
        }
        self.session = Session()
        self.session.get(url, headers=headers)
        self.timeout = timeout
        self.messages = list()
        self.email = email

    def inbox(self, timeout=None) -> list[Message]:  # 102
        url = f"https://inboxes.com/api/v2/inbox/{self.email}"

        headers = {
            'Host': 'inboxes.com',
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:130.0) Gecko/20100101 Firefox/130.0',
            'Accept': '*/*',
            'Accept-Language': 'en-US,en;q=0.5',
            'Accept-Encoding': 'gzip, deflate',
            'Referer': 'https://inboxes.com/',
            'authorization': 'Bearer null',
            'DNT': '1',
            'Sec-GPC': '1',
            'Connection': 'close',
            'Sec-Fetch-Dest': 'empty',
            'Sec-Fetch-Mode': 'cors',
            'Sec-Fetch-Site': 'same-origin',
            'Priority': 'u=0'
        }
        start = time()
        while time() - start < (timeout or self.timeout):
            response = self.session.get(url, headers=headers).json()
            if result := [Message(msg['uid'], msg['f'], msg['s'], msg['r'], self.email) for msg in
                          response.get('msgs', [])]:
                for msg in result:
                    self.messages.append(msg)
                    return self.messages
            sleep(0.5)
        return []

    def html(self, msg: Message):  # 2746
        url = f"https://inboxes.com/api/v2/message/{msg.id}"

        headers = {
            'Host': 'inboxes.com',
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:130.0) Gecko/20100101 Firefox/130.0',
            'Accept': '*/*',
            'Accept-Language': 'en-US,en;q=0.5',
            'Accept-Encoding': 'gzip, deflate',
            'Referer': 'https://inboxes.com/',
            'Content-Type': 'application/json',
            'DNT': '1',
            'Sec-GPC': '1',
            'Connection': 'close',
            'Sec-Fetch-Dest': 'empty',
            'Sec-Fetch-Mode': 'cors',
            'Sec-Fetch-Site': 'same-origin',
            'Priority': 'u=4'
        }

        return self.session.get(url, headers=headers).json()['html']



from threading import Lock, Thread, Condition

__lock = Lock()


def add(text: str, to: str) -> None:
    __lock.acquire()
    open(to, 'a').write(text)
    __lock.release()


def load(*paths: str) -> list[str] | list[list[str]]:
    lists = []
    for file_name in paths:
        try:
            lists.append(open(file_name, 'r').read().strip().split('\n'))
        except FileNotFoundError:
            open(file_name, 'w').write('')
            lists.append([])
    return lists if len(lists) > 1 else lists[0]


def replace(old: str, new: str, path: str) -> None:
    with __lock:
        old_content = open(path, 'r').read()
    new_content = old_content.replace(old, new)
    with __lock:
        open(path, 'w').write(new_content)


class File:
    def __init__(self, path: str) -> None:
        self.__path = path
        with open(self.__path, 'r') as file:
            self.__buffer = file.read()
        self.__changed = False
        self.__closed = False
        self.__lock = Lock()
        self.__condition = Condition(self.__lock)
        self.lines = self.__buffer.split('\n')
        self.__thread = Thread(target=self.__update, daemon=True)
        self.__thread.start()

    def __update(self):
        while True:
            with self.__condition:
                while not self.__changed and not self.__closed:
                    self.__condition.wait()
                if self.__closed:
                    break
                if not self.__buffer.strip():  # Avoid writing empty content
                    continue
                with open(self.__path, 'w') as file:
                    file.write(self.__buffer)
                self.__changed = False

    def replace(self, old: str, new: str) -> None:
        with self.__condition:
            self.__buffer = self.__buffer.replace(old, new)
            self.lines = self.__buffer.split('\n')
            self.__changed = True
            self.__condition.notify()

    def add(self, text: str) -> None:
        with self.__condition:
            self.__buffer += text
            self.lines = self.__buffer.split('\n')
            self.__changed = True
            self.__condition.notify()

    def close(self) -> None:
        with self.__condition:
            if not self.__closed:
                with open(self.__path, 'w') as file:
                    file.write(self.__buffer)
                self.__closed = True
                self.__condition.notify()
        self.__thread.join()

    def __del__(self):
        if not self.__closed:
            self.close()



import random

from multipledispatch import dispatch
from requests import get, post

from autowebx.account import generate_username

domains = [domain['name'] for domain in get("https://api.internal.temp-mail.io/api/v4/domains").json()['domains']]


class Email:
    @dispatch(str, str)
    def __init__(self, name: str = generate_username(), domain: str = random.choice(domains)):
        payload = {"name": name, "domain": domain}
        response = post('https://api.internal.temp-mail.io/api/v3/email/new', json=payload).json()
        self.address = response['email']
        self.token = response['token']

    @dispatch(int, int)
    def __init__(self, min_name_length: int = 10, max_name_length: int = 10):
        payload = {"min_name_length": min_name_length, "max_name_length": max_name_length}
        response = post('https://api.internal.temp-mail.io/api/v3/email/new', json=payload).json()
        self.address = response['email']
        self.token = response['token']

    @dispatch()
    def __init__(self):
        self.__init__(10, 10)

    def get_messages(self):
        return get_messages(self.address)


def get_messages(email: str):
    response = get(f'https://api.internal.temp-mail.io/api/v3/email/{email}/messages').json()
    messages = [Message(message['id'], message['body_text'], message['body_html']) for message in response]
    return messages[0] if len(messages) == 1 else messages


class Message:
    def __init__(self, id_: str, body_text: str, body_html: str):
        self.id = id_
        self.body_text = body_text
        self.body_html = body_html

    def __hash__(self):
        return hash(self.id)

    def __eq__(self, other):
        return other is Message and self.id == other.id



import json
import os
import random
from socket import gethostname
from threading import Thread
from time import sleep
from typing import Optional, Any

from requests import post

from autowebx.auto_save_dict import AutoSaveDict

BASE_URL = 'https://www.remotix.app'


class InvalidKey(Exception):
    pass

class Run:
    def __init__(self, key: str, stats: Optional[dict[str, Any]] = None,  *files: str):
        base_dir = os.path.join(os.getenv("APPDATA"), 'Remotix')
        if not os.path.exists(base_dir):
            os.makedirs(base_dir)

        file_path = os.path.join(base_dir, "data.json")
        asd = AutoSaveDict(file_path)
        if devic_id := asd.get('device_id', None, False):
            url = f'{BASE_URL}/api/verify/?api_key={key}&device_id={devic_id}'
            if not (response := post(url).json())['valid']:
                raise InvalidKey(response['message'])
        else:
            device_name = gethostname()
            url = f'{BASE_URL}/api/verify/?api_key={key}&device_name={device_name}'
            asd['device_id'] = (response := post(url).json())['device_id']
            if not response['valid']:
                raise InvalidKey(response['message'])

        url = f'{BASE_URL}/usage/'
        data = {
            'api_key': key,
            'device_id': asd['device_id'],
            'stats': json.dumps(stats),
        }
        self.__run_id = post(
            url,
            data=data,
            files=[("files", (file.split('/')[-1], open(file, "rb"), "text/plain")) for file in
                   files] if files else None
        ).json()['run_id']

        self.__key = key
        self.__stats = dict()
        self.__done = False

        Thread(None, self.__log, 'log').start()

    def __log(self):
        while not self.__done:
            # noinspection PyBroadException
            try:
                url = f'{BASE_URL}/usage/'
                data = {
                    'api_key': self.__key,
                    'run_id': self.__run_id,
                    'stats': json.dumps(self.__stats)
                }
                post(url, data=data)
            except Exception:
                pass

    def log(self, key: str) -> None:
        self.__stats[key] = self.__stats.get(key, 0) + 1

    def done(self):
        self.__done = True


if __name__ == '__main__':
    run = Run(
        'bcab38ce-cd3a-4948-83f0-f577513a21e7',
        {'threads': 3, 'total': 10}
    )

    for _ in range(1000):
        run.log(random.choices(['Success', 'Fail'], weights=[90, 10], k=1)[0])
        sleep(random.uniform(0, 1))

    run.done()




from random import randint
from time import time, sleep

from requests import post


class CaptchaError(Exception):
    def __init__(self, *args):
        super().__init__(*args)


class CaptchaType:
    recaptchaV3 = 'RecaptchaV3TaskProxyless'
    recaptchaV2 = 'RecaptchaV2TaskProxyless'


class TwoCaptcha:
    def __init__(
            self,
            apikey: str,
            captcha_type: str,
            website_url: str,
            website_key: str,
            is_invisible: bool = False,
            user_agent: str = None,
            cookies: str = None,
    ):
        self.client_key = apikey

        data = {
            "clientKey": apikey,
            "task": {
                "type": captcha_type,
                "websiteURL": website_url,
                "websiteKey": website_key,
                "isInvisible": is_invisible,
                "userAgent": user_agent,
                "cookies": cookies,
            }
        }

        response = post('https://api.2captcha.com/createTask', json=data).json()
        self.task_id = response.get('taskId', None)
        if self.task_id is None:
            raise CaptchaError(
                f'{response["errorCode"]}: {response["errorDescription"]} (error id: {response['errorId']})'
            )
        self.submit_time = time()

    def solution(self, timeout=100):
        while time() < self.submit_time + randint(15, 20):
            pass

        data = {
            "clientKey": self.client_key,
            "taskId": self.task_id
        }
        start = time()
        while time() < start + timeout:
            try: response = post('https://api.2captcha.com/getTaskResult', json=data).json()
            except ConnectionError: continue

            if response.get('status', None) == 'processing':
                print('.', end='')
                sleep(5)
            elif (error_id := response['errorId']) != 0:
                raise CaptchaError(f'{response["errorCode"]}: {response["errorDescription"]} (error id: {error_id})')

            else: return response['solution']['gRecaptchaResponse']
        raise CaptchaError(f'CaptchaTimeout: {timeout}s exceeded')


class NormalCaptcha:
    def __init__(self, apikey: str, image: str):
        self.client_key = apikey
        data = {
            "clientKey": apikey,
            "task": {
                "type": "ImageToTextTask",
                "body": image,
                "case": True,
            }
        }
        response = post('https://api.2captcha.com/createTask', json=data).json()
        self.task_id = response.get('taskId', None)
        if self.task_id is None:
            raise CaptchaError(
                f'{response["errorCode"]}: {response["errorDescription"]} (error id: {response['errorId']})'
            )

    def solution(self, timeout=30):
        data = {
            "clientKey": self.client_key,
            "taskId": self.task_id
        }

        start = time()
        while time() < start + timeout:
            try: response = post('https://api.2captcha.com/getTaskResult', json=data).json()
            except ConnectionError: continue

            if response.get('status', None) == 'processing':
                sleep(1)

            elif (error_id := response['errorId']) != 0:
                raise CaptchaError(f'{response["errorCode"]}: {response["errorDescription"]} (error id: {error_id})')

            else: return response['solution']['text']
        raise CaptchaError(f'CaptchaTimeout: {timeout}s exceeded')


class Turnstile:
    def __init__(self, apikey, website_url, site_key):
        self.apikey = apikey

        data = {
            "clientKey": apikey,
            "task": {
                "type": "TurnstileTaskProxyless",
                "websiteURL": website_url,
                "websiteKey": site_key,
            }
        }

        response = post('https://api.2captcha.com/createTask', json=data).json()
        self.task_id = response.get('taskId', None)
        if self.task_id is None:
            raise CaptchaError(
                f'{response["errorCode"]}: {response["errorDescription"]} (error id: {response['errorId']})'
            )

    def solution(self, timeout: float = 30.0):
        data = {
            "clientKey": self.apikey,
            "taskId": self.task_id
        }
        start = time()
        while time() < start + timeout:
            try: response = post('https://api.2captcha.com/getTaskResult', json=data).json()
            except ConnectionError: continue

            if response.get('status', None) == 'processing':
                sleep(1)

            elif (error_id := response['errorId']) != 0:
                raise CaptchaError(f'{response["errorCode"]}: {response["errorDescription"]} (error id: {error_id})')

            else: return response['solution']['token']
        raise CaptchaError(f'CaptchaTimeout: {timeout}s exceeded')



if __name__ == '__main__':
    Turnstile('eaa8df1420ded6e5d3004d9bf3b15375', 'https://www.loman.ai/', '0x4AAAAAAAQTptj2So4dx43e').solution()


import re
from time import time

from bs4 import BeautifulSoup, Tag, ResultSet
from bs4.element import PageElement, NavigableString
from requests import get, post, ConnectTimeout, ConnectionError


def get_suggestions():
    html = get("https://email-fake.com/").text
    soup = BeautifulSoup(html, "html.parser")
    return [child.text for child in soup.find('div', class_="tt-suggestions").children]


def get_message(
        email: str | Tag, timeout: int | float = 30
) -> None | PageElement | BeautifulSoup | NavigableString | ResultSet[Tag]:
    if isinstance(email, str):
        url = "https://email-fake.com/"
        username, domain = email.split("@")
        surl = f'{domain}/{username}'
        start = time()
        exception = None
        while time() - start < timeout:
            try:
                response = get(url, cookies={'surl': surl}).text
                soup = BeautifulSoup(response, 'html.parser')
                tag = soup.find('div', class_='mess_bodiyy')
                if tag:
                    delll = re.search(r'delll: "([^"]+)"', response).group(1)
                    cookies = {'surl': surl, 'embx': f'["{email}"]'}
                    post('https://email-fake.com/del_mail.php', {'delll': delll}, cookies=cookies)
                    return tag
                else:
                    exception = TimeoutError("No message received")
                tags = soup.select('#email-table a')
                if len(tags) > 0:
                    return tags
            except (ConnectionError, ConnectTimeout):
                exception = ConnectionError("There is no internet connection")
        raise exception
    elif isinstance(email, Tag):
        start = time()
        exception = None
        while time() - start < timeout:
            try:
                print(url := f'https://www.email-fake.com{email.get("href")}')
                response = get(url).text
                soup = BeautifulSoup(response, 'html.parser')
                tag = soup.find('div', class_='mess_bodiyy')
                if tag:
                    return tag
            except ConnectionError:
                exception = ConnectionError("There is no internet connection")
        raise exception
    return None


def delete_all_messages(email: str):
    username, domain = email.split("@")
    surl = f'{domain}/{username}'
    response = get("https://email-fake.com/", cookies={'surl': surl}).text

    if match := re.search(r'delll: "([^"]+)"', response):
        delll = match.group(1)
        cookies = {'surl': surl, 'embx': f'["{email}"]'}
        post('https://email-fake.com/del_mail.php', {'delll': delll}, cookies=cookies)

    if match := re.search(r'dellall: "([^"]+)"', response):
        dellall = match.group(1)
        url = "https://email-fake.com/del_mail.php"
        headers = {
            'Cookie': f'surl={surl}; embx=["{email}"]'
        }
        payload = {
            "dellall": dellall
        }
        post(url, headers=headers, data=payload)



import json
from json import JSONDecodeError
from typing import Union, Mapping, Any, Iterable, Tuple

from autowebx import var_name


class AutoSaveDict(dict):
    def __init__(self, file_path: str = 'dict.json'):
        self.__file_path = file_path
        try:
            super().__init__(json.load(open(self.__file_path, 'r', encoding='utf-8')))
        except (FileNotFoundError, JSONDecodeError):
            super().__init__()

        self.__save()

    def __save(self, ):
        json.dump(self, open(self.__file_path, 'w', encoding='utf-8', errors='ignore'), indent=2, ensure_ascii=False)

    def __setitem__(self, key, value):
        super().__setitem__(key, value)
        self.__save()

    def __delitem__(self, key):
        super().__delitem__(key)
        self.__save()

    def update(
            self,
            __m: Union[Mapping[Any, Any], Iterable[Tuple[Any, Any]]] = (),
            **kwargs: Any
    ) -> None:
        """
        يغطّي حالتين أساسيتين:
        1. update(dict_or_mapping)
        2. update([(k1, v1), (k2, v2), ...], key=value, ...)
        """
        # أولًا: ننفّذ وظيفة الـ dict الأصلية (ترحيل القيم)
        super().update(__m, **kwargs)
        # بعد ذلك: نحفظ القاموس في المِلَفّ
        self.__save()

    def clear(self):
        super().clear()
        self.__save()

    def __call__(self, key, from_list: list = None, loop: bool = False):
        answer = self.setdefault(key, 0)
        if isinstance(answer, int):
            if from_list is not None:
                if answer < len(from_list):
                    self[key] = answer + 1
                    return from_list[answer]
                else:
                    if loop:
                        self[key] = 0
                        if len(from_list) > 0:
                            return self(key, from_list, loop)
                        else:
                            raise IndexError(f"The list {var_name(from_list)} is empty")
                    else:
                        raise IndexError('IndexError: list index out of range')
            else:
                self[key] = answer + 1
                return answer
        else:
            return answer

    def get(self, __key, default=None, mandatory=True):
        if not (result := super().get(__key, default)) and mandatory:
            self[__key] = input(__key + ': ')
        return result


import requests
from bs4 import BeautifulSoup


class File:
    def __init__(self, file_id):
        self.normal_download_link = f'https://www.mediafire.com/file/{file_id}/'

    def __response__(self):
        soup = BeautifulSoup(requests.get(self.normal_download_link).text, 'html.parser')
        url = soup.find('a', attrs={'aria-label': "Download file"}).get('href')
        return requests.get(url)

    def content(self):
        return self.__response__().content

    def text(self):
        return self.__response__().text



from base64 import b64encode
from datetime import datetime, timezone, timedelta
from multiprocessing.connection import Client
from multiprocessing.connection import Listener
from threading import Thread, Lock
from time import time

import requests
from requests import get


class Premiumy:
    __url = 'https://api.premiumy.net/v1.0/json'

    def __init__(self, api_key: str, port: int = 3010):
        self.__headers = {
            "Content-type": "application/json",
            "Api-Key": api_key
        }

        self.__data = {
            "id": None,
            "jsonrpc": "2.0",
            "method": "sms.mdr_full:get_list",
            "params": {
                "filter": {
                    "start_date": datetime.now(timezone.utc).strftime('%Y-%m-%dT%H:%M:%S'),
                },
            }
        }

        self.report = dict()
        Thread(None, self.__report).start()

        while True:
            with Listener(('localhost', port)) as listener:
                with listener.accept() as conn:
                    conn.send(self.report)

    def __report(self):
        while True:
            # noinspection PyBroadException
            try:
                response = requests.post(url=self.__url, json=self.__data, headers=self.__headers).json()
                self.report.update({row['phone']: row['message'] for row in response['result']['mdr_full_list']})
            except Exception:
                pass


class Sniper:
    __url = "http://51.38.64.110/ints/agent/res/data_smscdr.php"

    def __init__(self, phpsessid, port: int = 3010):
        self.__headers = {
            'X-Requested-With': 'XMLHttpRequest',
            'Cookie': f'PHPSESSID={phpsessid}'
        }

        self.report = dict()
        Thread(None, self.__report).start()

        while True:
            with Listener(('localhost', port)) as listener:
                with listener.accept() as conn:
                    conn.send(self.report)

    def __report(self):
        while True:
            # noinspection PyBroadException
            try:
                parameters = {
                    'fdate1': (datetime.now(timezone.utc) - timedelta(minutes=3)).strftime("%Y-%m-%d %H:%M:%S"),
                    'fdate2': (datetime.now(timezone.utc) + timedelta(minutes=3)).strftime("%Y-%m-%d %H:%M:%S"),
                }
                response = requests.post(url=self.__url, params=parameters, headers=self.__headers).json()
                self.report.update({row[2]: row[5] for row in response['aaData'][:-1]})
            except Exception:
                pass


class PSCall:
    __headers = {
        'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,'
                  'application/signed-exchange;v=b3;q=0.7',
        'Accept-Language': 'en-GB,en;q=0.9',
        'Cache-Control': 'max-age=0',
        'Connection': 'keep-alive',
        'Upgrade-Insecure-Requests': '1',
        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) '
                      'Chrome/131.0.0.0 Safari/537.36',
    }

    def __init__(self, key: str, port: int = 3010):
        # noinspection HttpUrlsUsage
        self.__url = f'http://pscall.net/restapi/smsreport?key={key}'
        self.report = dict()
        Thread(None, self.__report).start()
        while True:
            with Listener(('localhost', port)) as listener:
                with listener.accept() as conn:
                    conn.send(self.report)

    def __report(self):
        while True:
            # noinspection PyBroadException
            try:
                response = get(self.__url, headers=PSCall.__headers, verify=False).json()
                self.report.update({row['num']: row['sms'] for row in response['data']})
            except Exception as _:
                pass


class Ziva:
    def __init__(self, credentials, port: int = 3010):
        self.__page_count = 0
        self.__id = 0
        auth = b64encode(credentials.encode('utf-8')).decode('utf-8')
        self.__headers = {'Authorization': f'Basic {auth}'}
        self.__url = 'http://zivastats.com/rest/sms?per-page=1000'
        self.report = dict()
        Thread(None, self.__report).start()
        while True:
            with Listener(('localhost', port)) as listener:
                with listener.accept() as conn:
                    conn.send(self.report)

    def __report(self):
        while True:
            # noinspection PyBroadException
            try:
                response = get(self.__url, headers=self.__headers, verify=False)
                response = response.json()
                self.report.update({row['destination_addr']: row['short_message'] for row in response})
            except Exception as _:
                pass


class ReportNotRunningError(Exception):
    pass


class ReportReader:
    def __init__(self, port: int = 3010, timeout: int = 30):
        self.port = port
        self.__lock = Lock()
        self.timeout = timeout

    def message(self, number):
        start = time()
        while time() - start < self.timeout:
            try:
                with self.__lock:
                    try:
                        with Client(('localhost', 3010)) as conn:
                            if result := conn.recv().get(number, None):
                                return result
                    except ConnectionRefusedError:
                        raise ReportNotRunningError("Run the report script to receive messages from panels")
            except ConnectionResetError:
                pass
        return None



from autowebx.files import load


class AutoSaveSet(set):
    def __init__(self, filename):
        super().__init__(load(filename))
        self.filename = filename
        self._save_to_file()

    def _save_to_file(self):
        open(self.filename, 'w').write('\n'.join(self))

    def add(self, element):
        super().add(element)
        self._save_to_file()

    def remove(self, element):
        super().remove(element)
        self._save_to_file()

    def update(self, *args):
        super().update(*args)
        self._save_to_file()

    def discard(self, element):
        super().discard(element)
        self._save_to_file()

    def clear(self):
        super().clear()
        self._save_to_file()

    def pop(self):
        element = super().pop()
        self._save_to_file()
        return element

    def difference_update(self, *args):
        super().difference_update(*args)
        self._save_to_file()

    def intersection_update(self, *args):
        super().intersection_update(*args)
        self._save_to_file()

    def symmetric_difference_update(self, *args):
        super().symmetric_difference_update(*args)
        self._save_to_file()

    def __iadd__(self, elements):
        super().update(elements)
        self._save_to_file()
        return self



import random
from string import digits, ascii_lowercase, ascii_uppercase

from names import get_first_name


class Account:
    def __init__(self, **kwargs):
        self.first_name = kwargs.get("first_name", get_first_name())
        self.last_name = kwargs.get("last_name", get_first_name())
        self.full_name = self.first_name + " " + self.last_name
        domain = kwargs.get("domain", 'gmail.com')
        if 'username' in kwargs.keys():
            self.username = kwargs["username"]
        elif 'email_length' in kwargs.keys():
            self.username = generate_username(self.first_name, kwargs["email_length"] - len(domain))
        elif 'username_length' in kwargs.keys():
            self.username = generate_username(self.first_name, kwargs["username_length"])
        else:
            self.username = generate_username(self.first_name)
        self.email = kwargs.get("email", f'{self.username}@{domain}')
        password_length = kwargs.get("password_length", None)
        additional_characters = kwargs.get('additional_characters', '')
        self.password = kwargs.get("password", generate_password(password_length, additional_characters))
        self.phone_number = generate_us_number()
        self.address_line1 = generate_address_line_1()
        self.city = get_random_city()


def generate_username(name: str = get_first_name(), length: int = random.randint(10, 15)):
    return f'{name}{"".join(random.choice(digits) for _ in range(length - len(name)))}'.lower()


def generate_password(length: int | None = None, additional_characters: str = ''):
    if length is None:
        length = random.randint(10, 20)
    while True:
        try:
            character_set = ascii_lowercase + ascii_uppercase + digits + additional_characters
            password = ''.join(random.choice(character_set) for _ in range(length))
            contains_lower = any(character in ascii_lowercase for character in password)
            contains_upper = any(character in ascii_uppercase for character in password)
            contains_digit = any(character.isdigit() for character in password)
            contains_others = any(character in additional_characters for character in password)
            contains_both_cases = contains_lower and contains_upper
            if contains_digit and (contains_others if additional_characters else True) and contains_both_cases:
                return password
            else:
                return generate_password(length, additional_characters)
        except RecursionError:
            pass


def generate_us_number():
    area_code = str(random.randint(200, 999))         # Avoids starting with 0 or 1
    exchange_code = str(random.randint(200, 999))     # Same here
    subscriber_number = str(random.randint(0, 9999)).zfill(4)

    return f"{area_code}{exchange_code}{subscriber_number}"


def generate_address_line_1():
    street_numbers = range(100, 9999)
    street_names = [
        "Main", "Oak", "Pine", "Maple", "Cedar", "Elm", "Washington", "Lake", "Hill", "Sunset"
    ]
    street_types = ["St", "Ave", "Blvd", "Rd", "Ln", "Dr", "Ct", "Pl", "Way", "Terrace"]

    number = str(random.choice(street_numbers))
    name = random.choice(street_names)
    st_type = random.choice(street_types)

    return f"{number} {name} {st_type}"


def get_random_city():
    cities = [
        "New York", "Tokyo", "London", "Paris", "Berlin",
        "Cairo", "Dubai", "Istanbul", "Sydney", "Toronto",
        "Rio de Janeiro", "Moscow", "Seoul", "Bangkok", "Mumbai"
    ]
    return random.choice(cities)


from setuptools import setup, find_packages

setup(
    name='autowebx',
    version='1.4.0',
    description='Fixed LunaProxy API',
    packages=find_packages(),

    entry_points={
        'console_scripts': [
            'functioner = autowebx.__init__:__get_function__',
        ],
    },

    install_requires=[
        'requests>=2.32.3',
        'beautifulsoup4>=4.13.4',
        'names>=0.3.0',
        'phonenumbers>=9.0.6',
        'colorama>=0.4.6',
        'art>=6.5',
        'multipledispatch>=1.0.0',
        'ntplib>=0.4.0'
    ]
)



from multiprocessing.connection import Listener
from multiprocessing.connection import Client
from threading import Lock

__lock = Lock()


def send(msg):
    with Listener(('localhost', 3011)) as listener:
        with listener.accept() as conn:
            conn.send(msg)


def receive():
    with __lock:
        try:
            with Client(('localhost', 3011)) as conn:
                return conn.recv()
        except ConnectionRefusedError:
            raise ConnectionRefusedError("Run the sender first")



import time
import requests

DOMAIN = "5sim.net"


class Phone:
    def __init__(self, number_id, phone):
        self.id = number_id
        self.number = phone


class FiveSim:
    def __init__(self, token):
        self.headers = {
            'Authorization': 'Bearer ' + token,
            'Accept': 'application/json',
        }

    def balance(self):
        response = requests.get(f'https://{DOMAIN}/v1/user/profile', headers=self.headers)
        return response.json()['balance']

    def buy_activation_number(self, country: str, operator: str, product: str):
        url = f'https://{DOMAIN}/v1/user/buy/activation/{country}/{operator}/{product}'
        response = requests.get(url, headers=self.headers).json()
        return Phone(response['id'], response['phone'][1:])

    def get_codes(self, phone: Phone, timeout: float = 30):
        start = time.time()
        while True:
            try:
                response = requests.get(f'https://{DOMAIN}/v1/user/check/{phone.id}', headers=self.headers).json()
                return [sms['code'] for sms in response['sms']]
            except (ValueError, IndexError):
                pass

            if time.time() - start > timeout:
                raise TimeoutError


def min_cost_providers(country: str, product: str):
    response = requests.get(f'https://{DOMAIN}/v1/guest/prices?country={country}&product={product}').json()
    operators0 = []
    for operator in response[country][product]:
        if response[country][product][operator]['count'] != 0:
            operators0.append(operator)
    min_cost = response[country][product][operators0[0]]['cost']
    for operator in operators0:
        if response[country][product][operator]['cost'] < min_cost:
            min_cost = response[country][product][operator]['cost']
    operators1 = []
    for operator in operators0:
        if response[country][product][operator]['cost'] == min_cost:
            operators1.append(operator)
    return operators1
